from logging_formatter.format import FormatLog
from utils import constants

class LatoLog:

    type = None

    def __init__(self,
                 type=constants.JSON):

        self.type = type

    def print_log(self, content):

        log = FormatLog()

        print(log.format_log(content=content,
                             type=self.type))



import json

from utils import constants
from datetime import datetime


class FormatLog:

    now_time = None

    def format_log(self,
                   dateformat=constants.DEFAULT_DATE_TEMPLATE,
                   type=constants.JSON,
                   content=None):

        now_time = datetime.now()

        formatted_now_time = now_time.strftime(dateformat)

        if type == constants.JSON:

            return json.dumps({
                "timestamp": formatted_now_time,
                **content
            })

        else:
            raise NotImplementedError





import os.path
from setuptools import setup, find_packages

# The directory containing this file
HERE = os.path.abspath(os.path.dirname(__file__))

# The text of the README file
with open(os.path.join(HERE, "README.md")) as fid:
    README = fid.read()

setup(
    name="LatoLog",
    version="0.1.0",
    author="Fábio Correia",
    author_email="fabioqcorreia@gmail.com",
    description="A package that makes customizing logs easier than expected",
    long_description=README,
    long_description_content_type="text/markdown",
    license="MIT",
    url="https://github.com/fabioqcorreia/LatoLog",
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    entry_points={
        "console_scripts": [
            "latolog=latolog.main:LatoLog"
        ]
    }
)



"""

Types class

Used for defining types

The supported ones should be:
- XML
- JSON

"""

from utils import constants


class Types:

    TYPE = None

    def __init__(self, type=constants.JSON):
        try:
            assert type == constants.XML or type == constants.JSON
            self.TYPE = type
        except TypeError:
            print("Type not supported")

    def get_type(self):
        return str(self.TYPE)

    def change_type(self, new_type=constants.JSON):
        self.TYPE = new_type
